aboutsummaryrefslogtreecommitdiff
path: root/sim/igen/lf.c
diff options
context:
space:
mode:
authorAndrew Cagney <cagney@redhat.com>2002-11-22 04:09:40 +0000
committerAndrew Cagney <cagney@redhat.com>2002-11-22 04:09:40 +0000
commitfeaee4bdbb06466822e886f5d1d30b9f1e04d985 (patch)
treec42f736c2cabb571ad4f2f6e0554d8b6c697f130 /sim/igen/lf.c
parentd85fe7f7fa4862015a50e89ec9b845e8155c2b0a (diff)
downloadgdb-feaee4bdbb06466822e886f5d1d30b9f1e04d985.zip
gdb-feaee4bdbb06466822e886f5d1d30b9f1e04d985.tar.gz
gdb-feaee4bdbb06466822e886f5d1d30b9f1e04d985.tar.bz2
2002-11-21 Andrew Cagney <ac131313@redhat.com>
* Makefile.in: Update copyright. IGEN contributed to the FSF. * filter.c, filter.h, filter_host.c, filter_host.h: Ditto. * gen-engine.c, gen-engine.h, gen-icache.c, gen-icache.h: Ditto. * gen-idecode.c, gen-idecode.h, gen-itable.c: Ditto. * gen-itable.h, gen-model.c, gen-model.h, gen-semantics.c: Ditto. * gen-semantics.h, gen-support.c, gen-support.h, gen.c: Ditto. * gen.h, igen.c, igen.h, ld-cache.c, ld-cache.h: Ditto. * ld-decode.c, ld-decode.h, ld-insn.c, ld-insn.h, lf.c: Ditto. * lf.h, misc.c, misc.h, table.c, table.h: Ditto.
Diffstat (limited to 'sim/igen/lf.c')
-rw-r--r--sim/igen/lf.c67
1 files changed, 36 insertions, 31 deletions
diff --git a/sim/igen/lf.c b/sim/igen/lf.c
index d209858..5364f41 100644
--- a/sim/igen/lf.c
+++ b/sim/igen/lf.c
@@ -1,22 +1,26 @@
-/* This file is part of the program psim.
+/* The IGEN simulator generator for GDB, the GNU Debugger.
- Copyright (C) 1994-1995, Andrew Cagney <cagney@highland.com.au>
+ Copyright 2002 Free Software Foundation, Inc.
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
+ Contributed by Andrew Cagney.
+
+ This file is part of GDB.
+
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2 of the License, or
+ (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with this program; if not, write to the Free Software
+ Foundation, Inc., 59 Temple Place - Suite 330,
+ Boston, MA 02111-1307, USA. */
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-
- */
#include <stdio.h>
@@ -259,27 +263,28 @@ lf_print__gnu_copyleft (lf *file)
case lf_is_c:
case lf_is_h:
nr += lf_printf(file, "\
/* This file is part of the program psim.\n\
\n\
- Copyright (C) 1994-1997, Andrew Cagney <cagney@highland.com.au>\n\
+ Copyright 2002 Free Software Foundation, Inc.\n\
\n\
- This program is free software; you can redistribute it and/or modify\n\
- it under the terms of the GNU General Public License as published by\n\
- the Free Software Foundation; either version 2 of the License, or\n\
- (at your option) any later version.\n\
+ This program is free software; you can redistribute it and/or modify\n\
+ it under the terms of the GNU General Public License as published by\n\
+ the Free Software Foundation; either version 2 of the License, or\n\
+ (at your option) any later version.\n\
\n\
- This program is distributed in the hope that it will be useful,\n\
- but WITHOUT ANY WARRANTY; without even the implied warranty of\n\
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the\n\
- GNU General Public License for more details.\n\
+ This program is distributed in the hope that it will be useful,\n\
+ but WITHOUT ANY WARRANTY; without even the implied warranty of\n\
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the\n\
+ GNU General Public License for more details.\n\
\n\
- You should have received a copy of the GNU General Public License\n\
- along with this program; if not, write to the Free Software\n\
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n\
+ You should have received a copy of the GNU General Public License\n\
+ along with this program; if not, write to the Free Software\n\
+ Foundation, Inc., 59 Temple Place - Suite 330,\n\
+ Boston, MA 02111-1307, USA.\n\
\n\
- --\n\
+ --\n\
\n\
- This file was generated by the program %s */\n\
+ This file was generated by the program %s */\n\
", filter_filename(file->program));
break;
default:
@@ -259,27 +263,28 @@ lf_print__gnu_copyleft (lf *file)
case lf_is_h:
nr += lf_printf(file, "\
-/* This file is part of the program psim.\n\
+/* This file is part of GDB.\n\
\n\